summaryrefslogtreecommitdiff
path: root/pkg/domain/entities/images.go
diff options
context:
space:
mode:
authorOpenShift Merge Robot <openshift-merge-robot@users.noreply.github.com>2020-04-29 17:04:22 +0200
committerGitHub <noreply@github.com>2020-04-29 17:04:22 +0200
commit27aa3a7837fa1c5379ff7ca1a9dcd6416b2ac685 (patch)
tree20d229709222de49e138b23e5790baf958c56338 /pkg/domain/entities/images.go
parentd1196d08d0c931885cf383ff4e568a855e8e4673 (diff)
parent5ee3af2d03b595bdff004ec179fc8a38e97cc5fe (diff)
downloadpodman-27aa3a7837fa1c5379ff7ca1a9dcd6416b2ac685.tar.gz
podman-27aa3a7837fa1c5379ff7ca1a9dcd6416b2ac685.tar.bz2
podman-27aa3a7837fa1c5379ff7ca1a9dcd6416b2ac685.zip
Merge pull request #6039 from vrothberg/enable-search-tests
Enable search tests
Diffstat (limited to 'pkg/domain/entities/images.go')
-rw-r--r--pkg/domain/entities/images.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkg/domain/entities/images.go b/pkg/domain/entities/images.go
index 442b2cf3c..69af365c0 100644
--- a/pkg/domain/entities/images.go
+++ b/pkg/domain/entities/images.go
@@ -141,8 +141,8 @@ type ImagePullOptions struct {
Quiet bool
// SignaturePolicy to use when pulling. Ignored for remote calls.
SignaturePolicy string
- // TLSVerify to enable/disable HTTPS and certificate verification.
- TLSVerify types.OptionalBool
+ // SkipTLSVerify to skip HTTPS and certificate verification.
+ SkipTLSVerify types.OptionalBool
}
// ImagePullReport is the response from pulling one or more images.
@@ -198,8 +198,8 @@ type ImageSearchOptions struct {
Limit int
// NoTrunc will not truncate the output.
NoTrunc bool
- // TLSVerify to enable/disable HTTPS and certificate verification.
- TLSVerify types.OptionalBool
+ // SkipTLSVerify to skip HTTPS and certificate verification.
+ SkipTLSVerify types.OptionalBool
}
// ImageSearchReport is the response from searching images.